@@ -199,8 +199,7 @@ get_document_attributes(HexDocument *doc)
 		return FALSE;
 
 	if(!stat(doc->file_name, &stats) &&
-	   S_ISREG(stats.st_mode) &&
-	   stats.st_size > 0) {
+	   S_ISREG(stats.st_mode)) {
 		doc->file_size = stats.st_size;
 
 		return TRUE;
@@ -312,18 +311,8 @@ static void
 hex_document_real_changed(HexDocument *doc, gpointer change_data,
 						  gboolean push_undo)
 {
-	GList *view;
-
 	if(push_undo && doc->undo_max > 0)
 		undo_stack_push(doc, change_data);
-
-	view = doc->views;
-
-	while(view) {
-		g_signal_emit_by_name(G_OBJECT(view->data), "data_changed",
-							  change_data);
-		view = g_list_next(view);
-	}
 }
 
 static void
@@ -429,8 +418,6 @@ HexDocument *
 hex_document_new()
 {
 	HexDocument *doc;
-	gchar *path_end;
-	int i;
 
 	doc = HEX_DOCUMENT (g_object_new (hex_document_get_type(), NULL));
 	g_return_val_if_fail (doc != NULL, NULL);
